Module layer_properties

Module layer_properties 

It contains related enums and struct which are used to manage, define and update various properties of a widget(viz a viz layer). You can import necessary types from this module to implement relevant features. See docs of related objects for their overview.

Modules

internal
It is an internal trait required for the implementation of PopupSlint .It is not to be used directly and contains internal types which are reluctantly exposed due to trait implementation. This module will probably be removed for a better alternative.
popup
This module holds all the related objects for creating and configuring

Structs

LayerAnchor
Specifies which edges and corners a layer should be placed at in the anchor rectangle.
WindowConf
WindowConf is an essential struct passed on to widget constructor functions (like invoke_spell of generated code) for defining the specifications of the widget.
WindowConfBuilder
A builder method for WindowConf.

Enums

BoardType
Dimension
This enum provides multiple ways for defininf the Dimensions of a widget. Thus making the prcess dynamic rather than being anchored to just pixels. if Full or Percentage is provided in Dimension, output name is compulsary to be defined. To maintain backward compatibility, Dimension implements into from u32 in which case it simply returns an instant of Dimension::Pixel.
LayerType
The z-depth of a layer.