Module popup

Module popup 

This module holds all the related objects for creating and configuring

Structs

PopupConf
Configure type used to determine the properties of a XDG poup.
PopupCore
It is an object required to create a SpellXDGPopup instance.

Enums

PopupAnchor
PopupGravity