pub struct WindowConf { /* private fields */ }Expand description
WindowConf is an essential struct passed on to widget constructor functions (like invoke_spell of generated code) for defining the specifications of the widget.
Panics
- Event loops (cast_spell) will panic if 0 is provided as width or height.
- Builder will also panic if percentage or full is used without specifying the monitor explicitly.
Implementations
Sourceimpl WindowConf
impl WindowConf
Sourcepub fn builder() -> WindowConfBuilder
pub fn builder() -> WindowConfBuilder
Creates a builder instance for creation of WindowConf, to view defaults
head over to documentation of WindowConf’s parameters.