WindowConfBuilder

Struct WindowConfBuilder 

pub struct WindowConfBuilder { /* private fields */ }
A builder method for WindowConf.

Implementations

Source

impl WindowConfBuilder

pub fn width<I: Into<Dimension>>(&mut self, width: I) -> &mut Self

Defines the widget width in pixels, fullscreen width or pecentage width of full screen. On setting values greater than the provided pixels of monitor, the widget offsets from monitor’s rectangular monitor space. It is important to note that the value should be the maximum width the widget will ever attain, not the current width in case of resizeable widgets. This value has full screen width as its default.

pub fn height<I: Into<Dimension>>(&mut self, height: I) -> &mut Self

Defines the widget height in pixels, fullscreen width or pecentage height of full screen. On setting values greater than the provided pixels of monitor, the widget offsets from monitor’s rectangular monitor space. It is important to note that the value should be the maximum height the widget will ever attain, not the current height in case of resizeable widgets. This value has full screen height as its default.

pub fn anchor_1(&mut self, anchor: Anchor) -> &mut Self

Defines the first anchor to which the window needs to be attached. View Anchor for related explaination of usage. If all values are None, then widget is displayed in the center of screen.

pub fn anchor_2(&mut self, anchor: Anchor) -> &mut Self

Defines the second anchor to which the window needs to be attached. View Anchor for related explaination of usage. If all values are None, then widget is displayed in the center of screen.

pub fn anchor_3(&mut self, anchor: Anchor) -> &mut Self

Defines the third anchor to which the window needs to be attached. View Anchor for related explaination of usage. If all values are None, then widget is displayed in the center of screen.

pub fn anchor_4(&mut self, anchor: Anchor) -> &mut Self

Defines the fourth anchor to which the window needs to be attached. View Anchor for related explaination of usage. If all values are None, then widget is displayed in the center of screen.

pub fn margins( &mut self, top: i32, right: i32, bottom: i32, left: i32, ) -> &mut Self

Defines the margin of widget from monitor edges, negative values make the widget go outside of monitor pixels if anchored to some edge(s). Otherwise, the widget moves to the opposite direction to the given pixels. Defaults to 0 for all sides.

pub fn layer_type(&mut self, layer: Layer) -> &mut Self

Defines the possible layer on which to define the widget. View Layer for more details. Defaults to Layer::Top.

pub fn board_interactivity(&mut self, board: KeyboardInteractivity) -> &mut Self

Defines the relation of widget with Keyboard. View KeyboardInteractivity for more details. Defauts to KeyboardInteractivity::None

pub fn exclusive_zone(&mut self, dimension: i32) -> &mut Self

Defines if the widget is exclusive of not, if not set, defaults to None, else sets to number of pixels to set as exclusive zone as i32. Defaults to no exclusive zone (i.e. None as mentioned).

pub fn monitor(&mut self, name: String) -> &mut Self

Defines the monitor name on which to spawn the window. It is necessary to set this value if a percentage dimention is given to either width or height; When no monitor is provided, the window is spawned on the default monitor.

pub fn natural_scroll(&mut self, scroll: bool) -> &mut Self

Defines if the method of scrolling for the widget should be natural or reverse. Defaults to reverse scrolling. Learn more about scrolling types here.

pub fn build(&self) -> Result<WindowConf, Box<dyn Error>>

Creates an instnce of WindowConf with the provided configurations. This function result in an error if width and height are not set or they are set to zero or monitor is not specified when full or percentage dimension is used.