generate_widgets

Macro generate_widgets 

macro_rules! generate_widgets {
    ($($slint_win:ty),+) => { ... };
}
This macro is responsible for generating Spell compatible types from Slint compatible types.

This macro takes in one or more Slint windows. Thus, it is important to place this macro alongside slint’s include_modules macro.

Example code snippet.

spell_framework::generate_widgets[AppWindow, BarWindow];