Components of this module are not be used by end user directly. This module contains certain reexports used by public facing macros like cast_spell and generate_widgets internally.
Macros
Structs
- Generic
- A generic event source wrapping a FD-backed type
- Interest
- Interest to register regarding the file descriptor
- Span
- A handle representing a span, with the capability to enter the span if it exists.
Enums
- Mode
- Possible modes for registering a file descriptor
- Post
Action - Possible actions that can be requested to the event loop by an event source once its events have been processed.