Module slint_adapter

Module slint_adapter 

This module contains relevent structs for slint side backend configurations. All structs mentioned are either internal or not used anymore. Still their implementation is public because they had to be set by the user of library in intial iterations of spell_framework.

Structs

SpellLayerShell
Previously needed to be implemented, now this struct is called and set internally when invoke_spell is called.
SpellLockShell
SpellMultiWinHandler
This struct is responsible for handling, initialising, updating and maintaining of various widgets that are being rendered simultaneously across monitors for your lock. It uses SpellSkiaWinAdapter internally. This struct is made public for documentation purposes (and was previously used by end user of library) but it is now not to be used directly.

Type Aliases

SpellSkiaWinAdapter
It is the main struct handling the rendering of pixels in the wayland window. It implements slint’s WindowAdapter trait. It is used internally by SpellMultiWinHandler and previously by SpellLayerShell. This adapter internally uses Skia 2D graphics library for rendering.