SpellLockShell

Struct SpellLockShell 

pub struct SpellLockShell {
    pub window_manager: Rc<RefCell<SpellMultiWinHandler>>,
    pub span: Span,
}
Slint Platform implementation for lock screens. This struct is used internally and it is provided here just for reference.

Fields

window_manager: Rc<RefCell<SpellMultiWinHandler>>

An instance of SpellMultiWinHandler.

span: Span

Span storing the logging context for `debug`` statements of slint for lock screens.

Implementations

Source

impl SpellLockShell

pub fn new(window_manager: Rc<RefCell<SpellMultiWinHandler>>) -> Self

Internal function that creates an instance of layer implementation given SpellMultiWinHandler wrapped in smart pointers.