pub struct SpellMultiWinHandler { /* private fields */ }Expand description
This struct is responsible for handling, initialising, updating and maintaining of various widgets that are being rendered simultaneously across monitors for your lock. It uses SpellSkiaWinAdapter internally. This struct is made public for documentation purposes (and was previously used by end user of library) but it is now not to be used directly.