PopupSlint

Trait PopupSlint 

pub trait PopupSlint {
    // Required methods
    fn create_new(settings: PopupCore) -> Self
       where Self: Sized;
    fn converter_popup(
        &self,
        wl_surface: &WlSurface,
        qh: &QueueHandle<SpellWin>,
    );
    fn inner(&self) -> &Popup;
    fn first_configure(&self) -> bool;
    fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>;
}
Trait necessary to be implemented for an UI object to become a popup. It is not the cleanest implementation and can be removed for a better/lighter alternative or design pattern. To see an implementation, check the popup example from spell-demo.

Required Methods

fn create_new(settings: PopupCore) -> Self
where Self: Sized,

Creates a new Instance of a slint frontend, wayland backend XDG popup.

fn converter_popup(&self, wl_surface: &WlSurface, qh: &QueueHandle<SpellWin>)

Internal method not to be called directly.

fn inner(&self) -> &Popup

Internal method not to be called directly.

fn first_configure(&self) -> bool

Internal method not to be called directly.

fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>

Internal method not to be called directly.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors