SpellAssociatedNew

Trait SpellAssociatedNew 

pub trait SpellAssociatedNew: Debug {
    // Required method
    fn on_call(&mut self) -> Result<(), Box<dyn Error>>;

    // Provided methods
    fn get_span(&self) -> Span { ... }
    fn is_locked(&self) -> bool { ... }
}
This is an internal trait implemented by objects generated from generate_widgets. It helps in running every SpellWidget (like SpellWin, SpellLock) through the same event_loop function.

Required Methods

fn on_call(&mut self) -> Result<(), Box<dyn Error>>

Internal method used to call to update UI in a loop.

Provided Methods

fn get_span(&self) -> Span

Internal method used to retrive logging span of a window.

fn is_locked(&self) -> bool

Internal method used to specify when to eliminate the event loop.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors