Hint

Enum Hint 

pub enum Hint {
Show 13 variants ActionIcons(bool), Category(String), DesktopEntry(String), ImagePath(String), Resident(bool), SoundFile(String), SoundName(String), SuppressSound(bool), Transient(bool), X(i32), Y(i32), Urgency(Urgency), Invalid,
}
Hints provided by a notification. Refer here for more details. Currently “image-data” and “image_data” hints are not supported.

Variants



ActionIcons(bool)

When set, a server that has the “action-icons” capability will attempt to interpret any action identifier as a named icon. The localized display name will be used to annotate the icon for accessibility purposes. The icon name should be compliant with the Freedesktop.org Icon Naming Specification.



Category(String)

The type of notification this is.



DesktopEntry(String)

This specifies the name of the desktop filename representing the calling program. This should be the same as the prefix used for the application’s .desktop file. An example would be “rhythmbox” from “rhythmbox.desktop”. This can be used by the daemon to retrieve the correct icon for the application, for logging purposes, etc.



ImagePath(String)

Alternative way to define the notification image. See Icons and Images.



Resident(bool)

When set the server will not automatically remove the notification when an action has been invoked. The notification will remain resident in the server until it is explicitly removed by the user or by the sender. This hint is likely only useful when the server has the “persistence” capability.



SoundFile(String)

The path to a sound file to play when the notification pops up.



SoundName(String)

A themeable named sound from the freedesktop.org sound naming specification to play when the notification pops up. Similar to icon-name, only for sounds. An example would be “message-new-instant”.



SuppressSound(bool)

Causes the server to suppress playing any sounds, if it has that ability. This is usually set when the client itself is going to play its own sound.



Transient(bool)

When set the server will treat the notification as transient and by-pass the server’s persistence capability, if it should exist.



X(i32)

Specifies the X location on the screen that the notification should point to. The “y” hint must also be specified.



Y(i32)

Specifies the Y location on the screen that the notification should point to. The “x” hint must also be specified.



Urgency(Urgency)

The urgency level.



Invalid

Invalid hint passed and not processed.