pub enum Urgency {
Low = 0,
Normal = 1,
Critical = 2,
}Expand description
The proposed urgency level by the notification, implementations of trait NotificationManager
can mark the accent color of their notifications based on this.
Variants
Low = 0
The urgency of the notification is low. Like completion of some unimportant task by some application.
Normal = 1
The urgency of the notification is normal. Used by most notifications.
Critical = 2
The urgency of the notification is critical. This urgency level is used by low battery, shutdown related etc notification types.