pub struct BlockingNotification;Expand description
Holds blocking methods to notify when a notification has bee closed.
Implementations
Sourceimpl BlockingNotification
impl BlockingNotification
Sourcepub fn call_close(
&self,
id: u32,
reason: CloseReason,
) -> Result<(), Box<dyn Error>>
pub fn call_close( &self, id: u32, reason: CloseReason, ) -> Result<(), Box<dyn Error>>
Method to ask the server to emit a signal for closing a particular notificaiton.