pub struct SpellLock { /* private fields */ }Expand description
SpellLock is a struct which represents a window lock. It can be run and initialised on a custom lockscreen implementation with slint. Know limitations include the abscence to verify from fingerprints and unideal issues on multi-monitor setup. You can add the path of binary of your lock in your compositor config and idle manager config to use the program. It will be linked to spell-cli directly in coming releases.
Example
Here is a minimal example of rust side, for complete code of slint, check the codebase of young-shell.
use spell_framework::cast_spell;
use std::{error::Error, sync::{Arc, RwLock}};
use slint::ComponentHandle;
use spell_framework::{layer_properties::ForeignController, wayland_adapter::SpellLock};
slint::include_modules!();
fn main() -> Result<(), Box<dyn Error>> {
let lock = SpellLock::invoke_lock_spell();
let lock_ui = LockScreen::new().unwrap();
let looop_handle = lock.get_handler();
lock_ui.on_check_pass({
let lock_handle = lock_ui.as_weak();
move |string_val| {
let lock_handle_a = lock_handle.clone().unwrap();
let lock_handle_b = lock_handle.clone().unwrap();
looop_handle.unlock(
None,
string_val.to_string(),
Box::new(move || {
lock_handle_a.set_lock_error(true);
}),
Box::new(move || {
lock_handle_b.set_is_lock_activated(false);
}),
);
}
});
lock_ui.set_is_lock_activated(true);
cast_spell(
lock,
None,
None::<fn(Arc<RwLock<Box<dyn ForeignController>>>)>,
)
}Implementations
Sourceimpl SpellLock
impl SpellLock
Sourcepub fn invoke_lock_spell() -> Self
pub fn invoke_lock_spell() -> Self
This function creates an instance of SpellLock which can be combined with slint windows to create a lockscreen.
Sourcepub fn get_handler(&self) -> LockHandle
pub fn get_handler(&self) -> LockHandle
Provides a lockscreen handler used to invoke the unlock
callback with the user entered password.For more details
view LockHandle.