SpellXDGPopup

Struct SpellXDGPopup 

pub struct SpellXDGPopup { /* private fields */ }
This struct holds the backend information for creating and managing a XDG popup in spell. It needs a PopupCore instance for initialisation and it needs to be initialsed before the corresponding slint frontend. It is better to wrap it in an external wrapper object along with frontend to satisfy trait requirements of PopupSlint. For example, refer to popup example in spell-demo.

Implementations

Source

impl SpellXDGPopup

pub fn new(popup_settings: PopupCore) -> Self

Creates an instance provided PopupCore.

pub fn popup(&self) -> &Popup

Method necessary for a PopupSlint implementation.

pub fn first_configure(&self) -> bool

Method necessary for a PopupSlint implementation.

pub fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>

Method necessary for a PopupSlint implementation.

pub fn converter_popup<'a>( &self, wl_surface: &'a WlSurface, qh: &'a QueueHandle<SpellWin>, )

Method necessary for a PopupSlint implementation.