WinHandle

Struct WinHandle 

pub struct WinHandle(pub LoopHandle<'static, SpellWin>);
This is a wrapper around calloop’s loop_handle for calling wayland specific features of SpellWin. It can be accessed from crate::wayland_adapter::SpellWin::get_handler.

Tuple Fields

0: LoopHandle<'static, SpellWin>

Implementations

Source

impl WinHandle

pub fn hide(&self)

pub fn show_again(&self)

pub fn toggle(&self)

pub fn grab_focus(&self)

pub fn remove_focus(&self)

pub fn add_input_region(&self, x: i32, y: i32, width: i32, height: i32)

pub fn subtract_input_region(&self, x: i32, y: i32, width: i32, height: i32)

pub fn add_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)

pub fn subtract_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)

pub fn set_exclusive_zone(&self, val: i32)

pub fn open_popup<T: PopupSlint + 'static>( &mut self, popup_conf: PopupConf, callback: Box<dyn FnOnce(u32)>, ) -> Result<u32, Box<dyn Error>>

Internally calls crate::wayland_adapter::SpellWin::open_popup. Since, the handler can’t be tuned to return anything(in this case the id), a callback is instead taken with ID as input, this is called after receiving the ID. It can be used to used to save the ID and perform actions with it.

pub fn close_popup(&self, id: u32)