pub enum Dimension {
Full,
Percentage(u32),
Pixel(u32),
}Expand description
This enum provides multiple ways for defininf the Dimensions of a widget. Thus
making the prcess dynamic rather than being anchored to just pixels. if Full
or Percentage is provided in Dimension, output name is compulsary to be defined.
To maintain backward compatibility, Dimension implements into from u32 in which
case it simply returns an instant of Dimension::Pixel.
Variants
Full
Full screen Dimension of the selected monitor.
Percentage(u32)
Whole number percentage Dimension of width/height, relative to the selected monitor.
Pixel(u32)
Definition of widgets in static pixels.