Module internal

Module internal 

It is an internal trait required for the implementation of PopupSlint .It is not to be used directly and contains internal types which are reluctantly exposed due to trait implementation. This module will probably be removed for a better alternative.

Structs

Popup
QueueHandle
A handle representing an EventQueue, used to assign objects upon creation.
WlSurface
an onscreen surface