This module holds all the related objects for creating and configuring
Structs
- Popup
Conf - Configure type used to determine the properties of a XDG poup.
- Popup
Core - It is an object required to create a
SpellXDGPopupinstance.
This module holds all the related objects for creating and configuring
SpellXDGPopup
instance.