WindowConfBuilder

Struct WindowConfBuilder 

pub struct WindowConfBuilder { /* private fields */ }

Implementations

Source

impl WindowConfBuilder

pub fn width<I: Into<u32>>(&mut self, width: I) -> &mut Self

pub fn height<I: Into<u32>>(&mut self, height: I) -> &mut Self

pub fn anchor_1(&mut self, anchor: Anchor) -> &mut Self

Sets first anchor of WindowConf::anchor.

pub fn anchor_2(&mut self, anchor: Anchor) -> &mut Self

Sets second anchor of WindowConf::anchor.

pub fn margins( &mut self, top: i32, right: i32, bottom: i32, left: i32, ) -> &mut Self

pub fn layer_type(&mut self, layer: Layer) -> &mut Self

pub fn board_interactivity(&mut self, board: KeyboardInteractivity) -> &mut Self

pub fn exclusive_zone(&mut self, dimention: i32) -> &mut Self

pub fn monitor(&mut self, name: String) -> &mut Self

pub fn natural_scroll(&mut self, scroll: bool) -> &mut Self

pub fn build(&self) -> Result<WindowConf, Box<dyn Error>>

Creates an instnce of WindowConf with the provided configurations. This function result in an error if width and height are not set or they are set to zero.