pub trait PopupSlint {
// Required methods
fn create_new(settings: PopupCore) -> Self
where Self: Sized;
fn converter_popup(
&self,
wl_surface: &WlSurface,
qh: &QueueHandle<SpellWin>,
);
fn inner(&self) -> &Popup;
fn first_configure(&self) -> bool;
fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>;
}Expand description
Trait necessary to be implemented for an UI object to become a popup. It is not the cleanest implementation and can be removed for a better/lighter alternative or design pattern. To see an implementation, check the popup example from spell-demo.
Required Methods
Sourcefn create_new(settings: PopupCore) -> Selfwhere
Self: Sized,
fn create_new(settings: PopupCore) -> Selfwhere
Self: Sized,
Creates a new Instance of a slint frontend, wayland backend XDG popup.
Sourcefn converter_popup(&self, wl_surface: &WlSurface, qh: &QueueHandle<SpellWin>)
fn converter_popup(&self, wl_surface: &WlSurface, qh: &QueueHandle<SpellWin>)
Internal method not to be called directly.
Sourcefn first_configure(&self) -> bool
fn first_configure(&self) -> bool
Internal method not to be called directly.
Sourcefn adapter(&self) -> &Rc<SpellSkiaWinAdapter>
fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>
Internal method not to be called directly.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".