set_notification

Function set_notification 

pub fn set_notification(win: &SpellWin, ui: Box<dyn NotificationManager>)
It is an internal function used in the expansion of cast_spell macro if the macro has a notification instance to run.