pub struct SpellXDGPopup { /* private fields */ }Expand description
This struct holds the backend information for creating and managing a XDG
popup in spell. It needs a PopupCore instance for initialisation
and it needs to be initialsed before the corresponding slint frontend. It is
better to wrap it in an external wrapper object along with frontend to satisfy
trait requirements of PopupSlint. For example, refer to popup example in
spell-demo.
Implementations
Sourceimpl SpellXDGPopup
impl SpellXDGPopup
Sourcepub fn popup(&self) -> &Popup
pub fn popup(&self) -> &Popup
Method necessary for a PopupSlint implementation.
Sourcepub fn first_configure(&self) -> bool
pub fn first_configure(&self) -> bool
Method necessary for a PopupSlint implementation.
Sourcepub fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>
pub fn adapter(&self) -> &Rc<SpellSkiaWinAdapter>
Method necessary for a PopupSlint implementation.
Sourcepub fn converter_popup<'a>(
&self,
wl_surface: &'a WlSurface,
qh: &'a QueueHandle<SpellWin>,
)
pub fn converter_popup<'a>( &self, wl_surface: &'a WlSurface, qh: &'a QueueHandle<SpellWin>, )
Method necessary for a PopupSlint implementation.