pub struct WinHandle(pub LoopHandle<'static, SpellWin>);Expand description
This is a wrapper around calloop’s loop_handle
for calling wayland specific features of SpellWin. It can be accessed from
crate::wayland_adapter::SpellWin::get_handler.
Tuple Fields
0: LoopHandle<'static, SpellWin>Implementations
Sourceimpl WinHandle
impl WinHandle
Sourcepub fn hide(&self)
pub fn hide(&self)
Internally calls crate::wayland_adapter::SpellWin::hide
Sourcepub fn show_again(&self)
pub fn show_again(&self)
Internally calls crate::wayland_adapter::SpellWin::show_again
Sourcepub fn toggle(&self)
pub fn toggle(&self)
Internally calls crate::wayland_adapter::SpellWin::toggle
Sourcepub fn grab_focus(&self)
pub fn grab_focus(&self)
Internally calls crate::wayland_adapter::SpellWin::grab_focus
Sourcepub fn remove_focus(&self)
pub fn remove_focus(&self)
Internally calls crate::wayland_adapter::SpellWin::remove_focus
Sourcepub fn add_input_region(&self, x: i32, y: i32, width: i32, height: i32)
pub fn add_input_region(&self, x: i32, y: i32, width: i32, height: i32)
Internally calls crate::wayland_adapter::SpellWin::add_input_region
Sourcepub fn subtract_input_region(&self, x: i32, y: i32, width: i32, height: i32)
pub fn subtract_input_region(&self, x: i32, y: i32, width: i32, height: i32)
Internally calls crate::wayland_adapter::SpellWin::subtract_input_region
Sourcepub fn add_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)
pub fn add_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)
Internally calls crate::wayland_adapter::SpellWin::add_opaque_region
Sourcepub fn subtract_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)
pub fn subtract_opaque_region(&self, x: i32, y: i32, width: i32, height: i32)
Internally calls crate::wayland_adapter::SpellWin::subtract_opaque_region
Sourcepub fn set_exclusive_zone(&self, val: i32)
pub fn set_exclusive_zone(&self, val: i32)
Internally calls crate::wayland_adapter::SpellWin::set_exclusive_zone
Sourcepub fn open_popup<T: PopupSlint + 'static>(
&mut self,
popup_conf: PopupConf,
callback: Box<dyn FnOnce(u32)>,
) -> Result<u32, Box<dyn Error>>
pub fn open_popup<T: PopupSlint + 'static>( &mut self, popup_conf: PopupConf, callback: Box<dyn FnOnce(u32)>, ) -> Result<u32, Box<dyn Error>>
Internally calls crate::wayland_adapter::SpellWin::open_popup. Since,
the handler can’t be tuned to return anything(in this case the id), a callback
is instead taken with ID as input, this is called after receiving the ID.
It can be used to used to save the ID and perform actions with it.
Sourcepub fn close_popup(&self, id: u32)
pub fn close_popup(&self, id: u32)
Internally calls crate::wayland_adapter::SpellWin::close_popup.